---
name: "\U0001F680 Feature proposal"
about: Feature Proposal
title: ''
assignees: ''

---

## Feature Proposal
<!--

Read https://github.com/edutap-eu/edutap.wallet_google/blob/main/CONTRIBUTING.md

Brief description of the feature.
-->

## Motivation

<!--
Reason or motivation this proposal was created
-->

## Assumptions

<!-- Preconditions -->

## Proposal & Implementation

<!--
Detailed proposal with implementation details and - if needed - possible variants to be discussed.
-->

## Risks

<!--
What will break/ affect existing installations of Plone after upgrade, including end user point of view, training efforts etc.
-->
